#
# spec file for package ghc-cmark
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1330
%define is_tumble 1
%endif

# is Leap 42.2+ or SLE12SP2+
%if 0%{?sle_version} >= 120200
%define is_sp2up 1
%endif

%global pkg_name cmark

%bcond_with tests

Name:           ghc-cmark
Version:        0.5.2.1
Release:        2.5
Summary:        Fast, accurate CommonMark (Markdown) parser and renderer
License:        BSD-3-Clause and BSD-2-Clause and MIT
Group:          System/Libraries

Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-text-devel
%if 0%{?is_tumble} || 0%{?is_sp2up} 
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcmark)
%endif
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
%endif
# End cabal-rpm deps

%description
This package provides Haskell bindings for <https://github.com/jgm/cmark
libcmark>, the reference parser for <http://commonmark.org CommonMark>, a fully
specified variant of Markdown. It includes sources for libcmark (0.19.0) and
does not require prior installation of the C library.

cmark provides the following advantages over existing Markdown libraries for
Haskell:

- Speed: Conversion speed is on par with the
<https://hackage.haskell.org/package/sundown sundown> library. We were unable
to measure precisely against <https://hackage.haskell.org/package/sundown
sundown>, which raised a malloc error when compiled into our benchmark suite.
Relative to other implementations: cmark was 82 times faster than
<https://hackage.haskell.org/package/cheapskate cheapskate>, 59 times faster
than <https://hackage.haskell.org/package/markdown markdown>, 105 times faster
than <https://hackage.haskell.org/package/pandoc pandoc>, and 2.8 times faster
than <https://hackage.haskell.org/package/discount discount>.

- Memory footprint: Memory footprint is on par with
<https://hackage.haskell.org/package/sundown sundown>. On one sample, the
library uses a fourth the memory that
<https://hackage.haskell.org/package/markdown markdown> uses, and less than a
tenth the memory that <https://hackage.haskell.org/package/pandoc pandoc> uses.

- Robustness: cmark can handle whatever is thrown at it, without the
exponential blowups in parsing time one can sometimes get with other libraries.
(The input 'bench/full-sample.md', for example, causes both
<https://hackage.haskell.org/package/pandoc pandoc> and
<https://hackage.haskell.org/package/markdown markdown> to grind to a halt.)

- Accuracy: cmark passes the CommonMark spec's suite of over 500 conformance
tests.

- Standardization: Since there is a spec and a comprehensive suite of tests, we
can have a high degree of confidence that any two CommonMark implementations
will behave the same. Thus, for example, one could use this library for
server-side rendering and <http://github.com/jgm/commonmark.js commonmark.js>
for client-side previewing.

- Ease of installation: cmark is portable and has minimal dependencies.

cmark does not provide Haskell versions of the whole
<http://github.com/jgm/cmark libcmark> API, which is built around mutable
'cmark_node' objects. Instead, it provides functions for converting CommonMark
to HTML (and other formats), and a function for converting CommonMark to a
'Node' tree that can be processed further using Haskell.

A note on security: This library does not attempt to sanitize HTML output.
We recommend using <https://hackage.haskell.org/package/xss-sanitize
xss-sanitize> to filter the output.

A note on stability: There is a good chance the API will change significantly
after this early release.


%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}
%if 0%{?is_tumble} || 0%{?is_sp2up} 
Requires:       pkgconfig(libcmark)
%endif

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}
%if 0%{?is_tumble} || 0%{?is_sp2up}
cabal-tweak-flag    pkgconfig   True
%endif

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%if %{with tests}
%cabal test
%endif

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Tue Jun 14 2016 mimi.vx@gmail.com
- use system libcmark on SLE12SP2+ and Leap:42.2
* Mon May 23 2016 mimi.vx@gmail.com
- update to 0.5.2.1
* Fri Apr 15 2016 mimi.vx@gmail.com
- use system libcmark on openSUSE:Tumbleweed
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 0.5.2
  * Add flag to allow building with an installed libcmark (Jens Petersen).
  * Updated to libcmark 0.25.2.
* Sun Jan 24 2016 mimi.vx@gmail.com
-  update to 0.5.1
  * Updated to libcmark 0.24.1.
* Sat Jan 23 2016 mimi.vx@gmail.com
- update to 0.5.0
  * Updated to libcmark 0.23.0.
  * API changes:
  + Added `OnEnter` and `OnExit` types.
  + In `NodeType`, `HRULE` is now `THEMATIC_BREAK`,
    `HTML` is `HTML_BLOCK`, `INLINE_HTML` is
    `HTML_INLINE`, `HEADER` is `HEADING`.  New
    constructors: `CUSTOM_INLINE`, `CUSTOM_BLOCK`.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 0.4.1
  * Updated to libcmark 0.22.0
  * Bumped version bounds for HUnit.
* Fri Aug 21 2015 cfarrell@suse.com
- license update: BSD-3-Clause and BSD-2-Clause and MIT
* Tue Jul 28 2015 mimi.vx@gmail.com
- update to 0.4.0.1
  * API changes:
    + Added `commonmarkToLaTeX`, `nodeToLaTeX`, `optSafe`.
    + Changed type of `commonmarkToMan` and `nodeToMan`,
    adding `Maybe Int` param for width.
    + Changed type of `nodeToCommonMark`, changing the `Int` width
    parameter to a `Maybe Int`.
  * Updated to cmark 0.21 sources.
* Fri Jun 12 2015 mimi.vx@gmail.com
- update to 0.3.4
  * Updated to libcmark 0.20.0.
* Sun May 31 2015 mimi.vx@gmail.com
- initial commit
